@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: lwgeodetic.h 10529 2012-10-23 21:19:28Z pramsey $
+ * $Id: lwgeodetic.h 10566 2012-10-25 22:17:39Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * Copyright 2009 Paul Ramsey <pramsey@cleverelephant.ca>
@@ -9,8 +9,19 @@
  *
  **********************************************************************/
 
+#ifndef _LWGEODETIC_H
+#define _LWGEODETIC_H 1
+
+/* For NAN */
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+
 #include <math.h>
-#include "libgeom.h"
+
+#ifndef NAN
+#define NAN 0.0/0.0
+#endif
 
 extern int gbox_geocentric_slow;
 
@@ -22,7 +33,7 @@ extern int gbox_geocentric_slow;
 typedef struct
 {
 	double lon;
-	double lat; 
+	double lat;
 } GEOGRAPHIC_POINT;
 
 /**
@@ -40,7 +51,7 @@ typedef struct
 typedef struct
 {
 	double measure;
-	uint32 index;
+	uint32_t index;
 } DISTANCE_ORDER;
 
 /**
@@ -54,10 +65,22 @@ typedef struct
 */
 #define signum(a) ((a) < 0 ? -1 : ((a) > 0 ? 1 : (a)))
 
-/*
-** Prototypes for internal functions.
-*/
 
+/**
+* Bitmask elements for edge_intersects() return value.
+*/
+#define PIR_NO_INTERACT    0x00
+#define PIR_INTERSECTS     0x01
+#define PIR_COLINEAR       0x02
+#define PIR_A_TOUCH_RIGHT   0x04
+#define PIR_A_TOUCH_LEFT  0x08
+#define PIR_B_TOUCH_RIGHT   0x10
+#define PIR_B_TOUCH_LEFT  0x20
+
+
+/*
+* Geodetic calculations
+*/
 void geog2cart(const GEOGRAPHIC_POINT *g, POINT3D *p);
 void cart2geog(const POINT3D *p, GEOGRAPHIC_POINT *g);
 void robust_cross_product(const GEOGRAPHIC_POINT *p, const GEOGRAPHIC_POINT *q, POINT3D *a);
@@ -73,15 +96,17 @@ int clairaut_geographic(const GEOGRAPHIC_POINT *start, const GEOGRAPHIC_POINT *e
 double sphere_distance(const GEOGRAPHIC_POINT *s, const GEOGRAPHIC_POINT *e);
 double sphere_distance_cartesian(const POINT3D *s, const POINT3D *e);
 int sphere_project(const GEOGRAPHIC_POINT *r, double distance, double azimuth, GEOGRAPHIC_POINT *n);
-int edge_calculate_gbox(const GEOGRAPHIC_EDGE *e, GBOX *gbox);
 int edge_calculate_gbox_slow(const GEOGRAPHIC_EDGE *e, GBOX *gbox);
+int edge_calculate_gbox(const POINT3D *A1, const POINT3D *A2, GBOX *gbox);
 int edge_intersection(const GEOGRAPHIC_EDGE *e1, const GEOGRAPHIC_EDGE *e2, GEOGRAPHIC_POINT *g);
+int edge_intersects(const POINT3D *A1, const POINT3D *A2, const POINT3D *B1, const POINT3D *B2);
 double edge_distance_to_point(const GEOGRAPHIC_EDGE *e, const GEOGRAPHIC_POINT *gp, GEOGRAPHIC_POINT *closest);
 double edge_distance_to_edge(const GEOGRAPHIC_EDGE *e1, const GEOGRAPHIC_EDGE *e2, GEOGRAPHIC_POINT *closest1, GEOGRAPHIC_POINT *closest2);
 void geographic_point_init(double lon, double lat, GEOGRAPHIC_POINT *g);
-int lwpoly_covers_point2d(const LWPOLY *poly, const GBOX *gbox, const POINT2D *pt_to_test);
-int ptarray_contains_point(const POINTARRAY *pa, const POINT2D *pt_outside, const POINT2D *pt_to_test);
-double ptarray_area_sphere(const POINTARRAY *pa, const POINT2D *pt_outside);
+int ptarray_contains_point_sphere(const POINTARRAY *pa, const POINT2D *pt_outside, const POINT2D *pt_to_test);
+int lwpoly_covers_point2d(const LWPOLY *poly, const POINT2D *pt_to_test);
+int ptarray_point_in_ring(const POINTARRAY *pa, const POINT2D *pt_outside, const POINT2D *pt_to_test);
+double ptarray_area_sphere(const POINTARRAY *pa);
 double latitude_degrees_normalize(double lat);
 double longitude_degrees_normalize(double lon);
 double ptarray_length_spheroid(const POINTARRAY *pa, const SPHEROID *s);
@@ -90,6 +115,13 @@ int crosses_dateline(const GEOGRAPHIC_POINT *s, const GEOGRAPHIC_POINT *e);
 void point_shift(GEOGRAPHIC_POINT *p, double shift);
 double longitude_radians_normalize(double lon);
 double latitude_radians_normalize(double lat);
+void vector_sum(const POINT3D *a, const POINT3D *b, POINT3D *n);
+double vector_angle(const POINT3D* v1, const POINT3D* v2);
+void vector_rotate(const POINT3D* v1, const POINT3D* v2, double angle, POINT3D* n);
+void normalize(POINT3D *p);
+void unit_normal(const POINT3D *P1, const POINT3D *P2, POINT3D *normal);
+double sphere_direction(const GEOGRAPHIC_POINT *s, const GEOGRAPHIC_POINT *e, double d);
+void ll2cart(const POINT2D *g, POINT3D *p);
 
 /*
 ** Prototypes for spheroid functions.
@@ -97,3 +129,5 @@ double latitude_radians_normalize(double lat);
 double spheroid_distance(const GEOGRAPHIC_POINT *a, const GEOGRAPHIC_POINT *b, const SPHEROID *spheroid);
 double spheroid_direction(const GEOGRAPHIC_POINT *r, const GEOGRAPHIC_POINT *s, const SPHEROID *spheroid);
 int spheroid_project(const GEOGRAPHIC_POINT *r, const SPHEROID *spheroid, double distance, double azimuth, GEOGRAPHIC_POINT *g);
+
+#endif /* _LWGEODETIC_H */
